/// <reference types="node" />
/**
 * Applies filters to a given image url
 * @example
 * const image = new StrangeFilters('Strange API token')
 * const blurredImage = await image.blur('Image Url', 6)
 */
export declare class Filters {
    private opts;
    constructor(token: string);
    /**
     * Blurs an image
     * @param image The image url
     * @param level Intensity of the blur
     */
    blur(image: string, level?: number): Promise<Buffer>;
    /**
     * Brightens an image
     * @param image The image url
     * @param amount Brightness amount
     */
    brighten(image: string, amount?: number): Promise<Buffer>;
    /**
     * Burns an image
     * @param image The image url
     * @param level Burn intensity
     */
    burn(image: string, level?: number): Promise<Buffer>;
    /**
     * Darkens an image
     * @param image The image url
     * @param amount Darkness amount
     */
    darken(image: string, amount?: number): Promise<Buffer>;
    /**
     * Applies Deepfry filter to an image
     * @param image The image url
     */
    deepfry(image: string): Promise<Buffer>;
    /**
     * Distorts an image
     * @param image The image url
     * @param level The level of distortion
     */
    distort(image: string, level: number): Promise<Buffer>;
    /**
     * Applies Greyscale filter to an image
     * @param image The image url
     */
    greyscale(image: string): Promise<Buffer>;
    /**
     * Inverts colors of an image
     * @param image The image url
     */
    invert(image: string): Promise<Buffer>;
    /**
     * Pixilates an image
     * @param image The image url
     * @param pixels Pixels
     */
    pixelate(image: string, pixels?: number): Promise<Buffer>;
    /**
     * Applies sepia filter to an image
     * @param image The image url
     */
    sepia(image: string): Promise<Buffer>;
    /**
     * Adds sharpness filter to your image
     * @param image The image url
     * @param level Sharpness intensity
     */
    sharpen(image: string, level?: number): Promise<Buffer>;
    /**
     * Adds Threshold filter to your image
     * @param image The image url
     * @param amount Threshold amount
     */
    threshold(image: string, amount: number): Promise<Buffer>;
}
