/// <reference types="node" />
/**
 * Various Image Generators
 * @example
 * const image = new StrangeGenerators('Strange API token')
 * const ad = await image.ad('Image Url')
 */
export declare class Generators {
    private opts;
    constructor(token: string);
    /**
     * Draws an image over Pokémon's "It's been 3000 years" meme
     * @param image The image url
     */
    pokemon3000Years(image: string): Promise<Buffer>;
    /**
     * Generates an Ad Image
     * @param image The image url
     */
    ad(image: string): Promise<Buffer>;
    /**
     * Generates an Affect Image
     * @param image The image url
     */
    affect(image: string): Promise<Buffer>;
    /**
     * Generates a batslap image
     * @param image1 The image 1 url
     * @param image2 The kmage 2 url
     */
    batslap(image1: string, image2: string): Promise<Buffer>;
    /**
     * Generates a beutiful image
     * @param image The image url
     */
    beautiful(image: string): Promise<Buffer>;
    /**
     * Generates a bed image
     * @param image1 The image 1 url
     * @param image2 Rhe image 2 url
     */
    bed(image1: string, image2: string): Promise<Buffer>;
    /**
     * Generates a bobross painting image
     * @param image The image url
     */
    bobross(image: string): Promise<Buffer>;
    /**
     * Draws an image over Super Smash Bros "Challenger Approaching" screen
     * @param image The image url
     * @param silhouetted Whether the image  should be silhouetted
     */
    challenger(image: string, silhouetted?: boolean): Promise<Buffer>;
    /**
     * Generates a changemymind image
     * @param text The text content
     */
    changemymind(text: string): Promise<Buffer>;
    /**
     * Generates a clown image
     * @param image The image url
     */
    clown(image: string): Promise<Buffer>;
    /**
     * Generates a clyde image
     * @param text The text content
     */
    clyde(text: string): Promise<Buffer>;
    /**
     * Generates a confusedstonk image
     * @param image The image url
     */
    confusedstonk(image: string): Promise<Buffer>;
    /**
     * Generates a delete image
     * @param image The image url
     */
    delete(image: string): Promise<Buffer>;
    /**
     * Draws an image and the text you specify as a demotivational poster
     * @param title The title for the poster
     * @param text The text as the poster desceiption
     * @param image The image url
     */
    demotivational(title: string, text: string, image: string): Promise<Buffer>;
    /**
     * Draws an image avatar over the screen of Dexter from Pokémon
     * @param image The image url
     */
    dexter(image: string): Promise<Buffer>;
    /**
     * Generates a Discord black overlay
     * @param image The image url
     */
    discordblack(image: string): Promise<Buffer>;
    /**
     * Generates a Discord blue overlay
     * @param image The image url
     */
    discordblue(image: string): Promise<Buffer>;
    /**
     * Generates a facepalm image
     * @param image1 The image 1 url
     * @param image2 The image 2 url
     */
    doublestonk(image1: string, image2: string): Promise<Buffer>;
    /**
     * Generates a facepalm image
     * @param image The image url
     */
    facepalm(image: string): Promise<Buffer>;
    /**
     * Draws baseImage over overlayImage
     * @param image1 The image 1 url
     * @param image2 The image 2 url
     */
    fusion(image1: string, image2: string): Promise<Buffer>;
    /**
     * Sends a Gru's Plan meme with steps of your choice
     * @param firstStep The first step of the plan
     * @param secondStep The second step of the plan
     * @param thirdStep The third step of the plan
     * @param fourthStep The fourth step of the plan
     */
    gruPlan(firstStep: string, secondStep: string, thirdStep: string, fourthStep: string): Promise<Buffer>;
    /**
     * Generates a heartbreaking image
     * @param image The image url
     */
    heartbreaking(image: string): Promise<Buffer>;
    /**
     * Generates a hitler image
     * @param image The image url
     */
    hitler(image: string): Promise<Buffer>;
    /**
     * Generates a jail image
     * @param image The image url
     */
    jail(image: string): Promise<Buffer>;
    /**
     * Generates a jokeoverhead image
     * @param image The image url
     */
    jokeoverhead(image: string): Promise<Buffer>;
    /**
     * Generates a karaba image
     * @param image The image url
     */
    karaba(image: string): Promise<Buffer>;
    /**
     * Generates a kiss image
     * @param image1 The image 1 url
     * @param image2 the image 2 url
     */
    kiss(image1: string, image2: string): Promise<Buffer>;
    /**
     * Draws an image behind Kyon shooting a gun
     * @param image The image url
     */
    kyonGun(image: string): Promise<Buffer>;
    /**
     * Sends a "Lisa Presentation" meme with the presentation of your choice
     * @param text A text for the meme
     */
    lisaPresentation(text: string): Promise<Buffer>;
    /**
     * Generates a mikkelsen meme
     * @param image The image url
     */
    mikkelsen(image: string): Promise<Buffer>;
    /**
     * Generates a mms image
     * @param image The image url
     */
    mirror(image: string): Promise<Buffer>;
    /**
     * Generates a mms image
     * @param image The image url
     */
    mms(image: string): Promise<Buffer>;
    /**
     * Generates a notstonk image
     * @param image The image url
     */
    notstonk(image: string): Promise<Buffer>;
    /**
     * Generates a ohno image
     * @param text The text content
     */
    ohno(text: string): Promise<Buffer>;
    /**
     * Sends a Plankton's Plan meme with steps of your choice
     * @param firstStep The first step of the plan
     * @param secondStep The second step of the plan
     * @param thirdStep The third step of the plan
     * @param fourthStep The fourth step of the plan
     */
    planktonPlant(firstStep: string, secondStep: string, thirdStep: string, fourthStep: string): Promise<Buffer>;
    /**
     * Generates a poutine image
     * @param image The image url
     */
    poutine(image: string): Promise<Buffer>;
    /**
     * Generates a rip image
     * @param image The image url
     */
    rip(image: string): Promise<Buffer>;
    /**
     * Generates a shit image
     * @param image The image url
     */
    shit(image: string): Promise<Buffer>;
    /**
     * Generates a snyder meme
     * @param image The image url
     */
    snyder(image: string): Promise<Buffer>;
    /**
     * Generates a spank image
     * @param image1 The image 1 url
     * @param image2 The image 2 url
     */
    spank(image1: string, image2: string): Promise<Buffer>;
    /**
     * Generates a stonk image
     * @param image The image url
     */
    stonk(image: string): Promise<Buffer>;
    /**
     * Generates a tatoo image
     * @param image The image url
     */
    tattoo(image: string): Promise<Buffer>;
    /**
     * Generates a thomas image
     * @param image The image url
     */
    thomas(image: string): Promise<Buffer>;
    /**
     * Generates a trash image
     * @param image The image url
     */
    trash(image: string): Promise<Buffer>;
    /**
     * Generates a wanted image
     * @param image The image url
     */
    wanted(image: string): Promise<Buffer>;
    /**
     * Draws an image over Gravity Falls "Oh, this? This is worthless." meme
     * @param image The image url
     */
    worthless(image: string): Promise<Buffer>;
    /**
     * Sends a youtube comment with the text of your choice
     * @param image the username avatar url
     * @param username The username as the comment author
     * @param text The text to be used in the returned image results
     */
    youtube(image: string, username: string, text: string): Promise<Buffer>;
}
