"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Overlays = void 0;
const package_json_1 = require("../../package.json");
const getBuffer_1 = require("../utils/getBuffer");
/**
 * Various Image Overlays
 * @example
 * const image = new StrangeOverlays('Strange API token')
 * const approve = await image.approve('Image Url')
 */
class Overlays {
    opts;
    constructor(token) {
        this.opts = {
            headers: {
                Authorization: `Bearer ${token}`,
            },
        };
    }
    /**
     * Draws an 'approved' stamp over an image
     * @param image the image url
     */
    async approve(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/approved`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Draws an image with the brazzers logo on the side
     * @param image the image url
     */
    async brazzers(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/brazzers`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Draws gay overlay on an image
     * @param image the image url
     */
    async gay(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/gay`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Draws an image over a halloween border
     * @param image the image url
     */
    async halloween(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/halloween`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Draws a "Thug Life" over an image
     * @param image the image url
     */
    async thugLife(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/thuglife`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Draws an image with "To Be Continued..." arrow
     * @param image the image url
     */
    async toBeContinued(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/to-be-continued`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Generates a wasted image
     * @param image the image url
     */
    async wasted(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/overlays/wasted`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
}
exports.Overlays = Overlays;
