/// <reference types="node" />
/**
 * Various Image Utilities
 * @example
 * const image = new StrangeUtils('Strange API token')
 * const circledImage = await image.circle('Image Url')
 */
export declare class Utils {
    private opts;
    constructor(token: string);
    /**
     * Circles the provided image
     * @param image the image url
     */
    circle(image: string): Promise<Buffer>;
    /**
     * Generates a color from hex color code
     * @param code The hex color code
     */
    color(code: string): Promise<Buffer>;
    /**
     * Denoise an image
     * @param image the image url
     */
    denoise(image: string): Promise<Buffer>;
    /**
     * Generates a farewell card
     * @param options {@link GreetingCardOptions} - The options for Farewell card
     */
    farewellCard(options: GreetingCardOptions): Promise<Buffer>;
    /**
     * Generates a rank card
     * @param options {@link RankCardOptions} - The options for Rank card
     */
    rankCard(options: RankCardOptions): Promise<Buffer>;
    /**
     * Generates a spotify card
     * @param options {@link SpotifyCardOptions} - The options for Spotify card
     */
    spotifyCard(options: SpotifyCardOptions): Promise<Buffer>;
    /**
     * Generates a Welcome card
     * @param options {@link GreetingCardOptions} - The options for welcome card
     */
    welcomeCard(options: GreetingCardOptions): Promise<Buffer>;
}
interface GreetingCardOptions {
    avatar?: string;
    name?: string;
    discriminator?: string;
    count?: number;
    guild?: string;
    background?: string;
}
interface RankCardOptions {
    avatar?: string;
    currentXP?: number;
    reqXP?: number;
    level: number;
    status?: "dnd" | "idle" | "online" | "offline" | "streaming";
    name?: string;
    username?: string;
    discriminator?: string;
    barColor?: string;
    backgroundImage?: string;
    backgroundColor?: string;
}
interface SpotifyCardOptions {
    image: string;
    author: string;
    album: string;
    start: number;
    end: number;
    title: string;
}
export {};
