"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Utils = void 0;
const package_json_1 = require("../../package.json");
const getBuffer_1 = require("../utils/getBuffer");
/**
 * Various Image Utilities
 * @example
 * const image = new StrangeUtils('Strange API token')
 * const circledImage = await image.circle('Image Url')
 */
class Utils {
    opts;
    constructor(token) {
        this.opts = {
            headers: {
                Authorization: `Bearer ${token}`,
            },
        };
    }
    /**
     * Circles the provided image
     * @param image the image url
     */
    async circle(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/circle`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Generates a color from hex color code
     * @param code The hex color code
     */
    async color(code) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/color`);
        if (code)
            endpoint.searchParams.append("code", code);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Denoise an image
     * @param image the image url
     */
    async denoise(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/denoise`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Generates a farewell card
     * @param options {@link GreetingCardOptions} - The options for Farewell card
     */
    async farewellCard(options) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/farewell-card`);
        if (options.avatar)
            endpoint.searchParams.append("avatar", options.avatar);
        if (options.background)
            endpoint.searchParams.append("bkg", options.background);
        if (options.count)
            endpoint.searchParams.append("count", options.count.toString());
        if (options.discriminator)
            endpoint.searchParams.append("discriminator", options.discriminator);
        if (options.guild)
            endpoint.searchParams.append("guild", options.guild);
        if (options.name)
            endpoint.searchParams.append("name", options.name);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Generates a rank card
     * @param options {@link RankCardOptions} - The options for Rank card
     */
    async rankCard(options) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/rank-card`);
        if (options.level)
            endpoint.searchParams.append("", options.level.toString());
        if (options.avatar)
            endpoint.searchParams.append("avatar", options.avatar);
        if (options.currentXP)
            endpoint.searchParams.append("currentxp", options.currentXP.toString());
        if (options.reqXP)
            endpoint.searchParams.append("reqxp", options.reqXP.toString());
        if (options.status)
            endpoint.searchParams.append("status", options.status);
        if (options.name)
            endpoint.searchParams.append("name", options.name);
        if (options.username)
            endpoint.searchParams.append("username", options.username);
        if (options.discriminator)
            endpoint.searchParams.append("discriminator", options.discriminator);
        if (options.barColor)
            endpoint.searchParams.append("barcolor", options.barColor);
        if (options.backgroundImage)
            endpoint.searchParams.append("bgImage", options.backgroundImage);
        if (options.backgroundColor)
            endpoint.searchParams.append("bgColor", options.backgroundColor);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Generates a spotify card
     * @param options {@link SpotifyCardOptions} - The options for Spotify card
     */
    async spotifyCard(options) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/spotify-card`);
        if (options.image)
            endpoint.searchParams.append("image", options.image);
        if (options.author)
            endpoint.searchParams.append("author", options.author);
        if (options.album)
            endpoint.searchParams.append("album", options.album);
        if (options.start || options.start === 0)
            endpoint.searchParams.append("start", options.start.toString());
        if (options.end || options.start === 0)
            endpoint.searchParams.append("end", options.end.toString());
        if (options.title)
            endpoint.searchParams.append("title", options.title);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Generates a Welcome card
     * @param options {@link GreetingCardOptions} - The options for welcome card
     */
    async welcomeCard(options) {
        const endpoint = new URL(`${package_json_1.baseUrl}/utils/welcome-card`);
        if (options.avatar)
            endpoint.searchParams.append("avatar", options.avatar);
        if (options.background)
            endpoint.searchParams.append("bkg", options.background);
        if (options.count)
            endpoint.searchParams.append("count", options.count.toString());
        if (options.discriminator)
            endpoint.searchParams.append("discriminator", options.discriminator);
        if (options.guild)
            endpoint.searchParams.append("guild", options.guild);
        if (options.name)
            endpoint.searchParams.append("name", options.name);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
}
exports.Utils = Utils;
