"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StrangeImage = exports.StrangeUtils = exports.StrangeOverlays = exports.StrangeGenerators = exports.StrangeFilters = void 0;
const classes_1 = require("./classes");
Object.defineProperty(exports, "StrangeFilters", { enumerable: true, get: function () { return classes_1.Filters; } });
Object.defineProperty(exports, "StrangeGenerators", { enumerable: true, get: function () { return classes_1.Generators; } });
Object.defineProperty(exports, "StrangeOverlays", { enumerable: true, get: function () { return classes_1.Overlays; } });
Object.defineProperty(exports, "StrangeUtils", { enumerable: true, get: function () { return classes_1.Utils; } });
/**
 * An API Wrapper for Strange API, an image manipulator.
 * @example
 * // Example usage
 * const image = new StrangeImage('Strange API token')
 * const blurredImage = await image.filters.blur('Image Url', 6)
 */
class StrangeImage {
    constructor(token) {
        if (!token)
            throw new Error("Strange API Token must be passed");
        this.filters = new classes_1.Filters(token);
        this.generators = new classes_1.Generators(token);
        this.overlays = new classes_1.Overlays(token);
        this.utils = new classes_1.Utils(token);
    }
    /**
     * Class with filter methods for manipulating images
     */
    filters;
    /**
     * Class with generators methods for manipulating images
     */
    generators;
    /**
    * Class with overlays methods for manipulating images
    */
    overlays;
    /**
    * Class with utils methods for manipulating images
    */
    utils;
}
exports.StrangeImage = StrangeImage;
// Export Main class by default
exports.default = StrangeImage;
